==> sigutils-2.4.2.tar.gz: sigutils-2.4.2/SigUtils/inifile.py <==
# -*- coding: iso-8859-1 -*-

# Classe IniFile
# Autor: Luiz Fernando 
# Funcao: Ler e/ou gravar arquivos de configuracao no formato secao
# Metodos: 
#  Construtor: Informar nome do arquivo .ini
#  lerIniFile: Ler o dado do arquivo qdo se informa a secao e o dado a ser lido.
#              Em caso de nao existir a secao ou o dado, retorna -1
#  gravarIniFile: Informar secao, atributo(dado) e valor do atributo
#

__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.03"
__DataAlteracao__ = "24/10/2008"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('inifile.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tLeitura e gravacao de arquivos de configuracao'
        else:
           print('\n\ninifile.py - Leitura e gravacao de arquivos de configuracao \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\ninifile.py - Leitura e gravacao de arquivos de configuracao \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')

import ConfigParser
        
class IniFile:
    """sintaxe: IniFile(NomeDoArquivo) -> Objeto 
       IniFile permite trabalhar com arquivos de configuracao
       tipo secao '[NomeDaSecao]'
       Para qualquer erro, retorna -1"""

    def __init__(self, arquivo):
        self.arquivo = arquivo
        self.config = ConfigParser.ConfigParser()

    def lerIniFile(self, secao, atributo):
        """lerIniFile(NomeDaSecao, NomeDoAtributo)
           Ler o arquivo de configuracao para a secao especificada 
           'NomeDaSecao' e atributo especificado 'NomeDoAtributo', 
           retornando o valor do atributo."""

        self.secao = secao
        self.atributo = atributo
        self.config.read(self.arquivo)
        try:
           dado = self.config.get(self.secao, self.atributo)
        except:
           dado = -1

        return dado

    def gravarIniFile(self, secao, atributo, dado):
        """GravarIniFile(NomeDaSecao, NomeDoAtributo, ValorDoAtributo)
           Gravar no arquivo de configuracao a secao especificada 'NomeDaSecao', 
           o atributo especificado 'NomeDoAtributo' e o valor especifidado do 
           atributo 'ValorDoAtributo'
           Obs.: A secao ja deve existir"""

        self.secao = secao
        self.atributo = atributo
        self.dado = dado
        try:
           self.config.set(self.secao, self.atributo, self.dado)
           file = open(self.arquivo, "w")
           self.config.write(file)
           file.close()
        except:
           return -1
        else:
           return 0



# fim de arquivo

==> sigutils-3.1.11.tar.gz: sigutils-3.1.11/SigUtils/inifile.py <==
# -*- coding: iso-8859-1 -*-

# Classe IniFile
# Autor: Luiz Fernando 
# Funcao: Ler e/ou gravar arquivos de configuracao no formato secao
# Metodos: 
#  Construtor: Informar nome do arquivo .ini
#  lerIniFile: Ler o dado do arquivo qdo se informa a secao e o dado a ser lido.
#              Em caso de nao existir a secao ou o dado, retorna -1
#  gravarIniFile: Informar secao, atributo(dado) e valor do atributo
#

__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.03"
__DataAlteracao__ = "24/10/2008"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print(('inifile.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) +
                  '\tLeitura e gravacao de arquivos de configuracao')
        else:
            print(('\n\ninifile.py - Leitura e gravacao de arquivos de configuracao \n'
                   + 'Versao: '+ __Versao__ + '\n' + 'Data: '+ __DataAlteracao__ + '\n'))
    except:
        print(('\n\ninifile.py - Leitura e gravacao de arquivos de configuracao \n'
               + 'Versao: ' + __Versao__ + '\n'
               + 'Data: ' + __DataAlteracao__ + '\n'))

import configparser
        

class IniFile:
    """sintaxe: IniFile(NomeDoArquivo) -> Objeto 
       IniFile permite trabalhar com arquivos de configuracao
       tipo secao '[NomeDaSecao]'
       Para qualquer erro, retorna -1"""

    def __init__(self, arquivo):
        self.arquivo = arquivo
        self.config = configparser.ConfigParser()

    def lerIniFile(self, secao, atributo):
        """lerIniFile(NomeDaSecao, NomeDoAtributo)
           Ler o arquivo de configuracao para a secao especificada 
           'NomeDaSecao' e atributo especificado 'NomeDoAtributo', 
           retornando o valor do atributo."""

        self.secao = secao
        self.atributo = atributo
        self.config.read(self.arquivo)
        try:
           dado = self.config.get(self.secao, self.atributo)
        except:
           dado = -1

        return dado

    def gravarIniFile(self, secao, atributo, dado):
        """GravarIniFile(NomeDaSecao, NomeDoAtributo, ValorDoAtributo)
           Gravar no arquivo de configuracao a secao especificada 'NomeDaSecao', 
           o atributo especificado 'NomeDoAtributo' e o valor especifidado do 
           atributo 'ValorDoAtributo'
           Obs.: A secao ja deve existir"""

        self.secao = secao
        self.atributo = atributo
        self.dado = dado
        try:
           self.config.set(self.secao, self.atributo, self.dado)
           file = open(self.arquivo, "w")
           self.config.write(file)
           file.close()
        except:
           return -1
        else:
           return 0



# fim de arquivo
